Skip to main contentCrate ninja_files_kustomize
Source - KUSTOMIZE
- KUSTOMIZE_DEPS
- KUSTOMIZE_TEMPLATE
- depfiles
- leaf
- Creates a file builder that will just build this file
It wont create templating so others can depend on it.
Useful for kubectl apply
- node
- Build an intermediate kustomize file
This will also add rules for creating a ‘kustomization.yaml’
that other stages could depend on